@@ -3,6 +3,7 @@ from typing import NoReturn
 
 from telegram import Update, ext
 
+from botty.errors import FieldError
 from botty.handlers.handler import Handler
 from botty.handlers.types import Context, PTBHandler
 from botty.types import Bot
@@ -20,25 +21,20 @@ class UpdateHandler(Handler, ABC):
     @classmethod
     async def _handle(cls, update: Update, context: Context) -> None:
         handler = cls(update, context)
+        await handler.prepare()
         await handler.callback()
 
     @abstractmethod
     async def callback(self) -> None:
         """Will be called to handle update."""
 
+    async def prepare(self) -> None:
+        """Will be called before `callback`."""
+
     @property
     def bot(self) -> Bot:
         raw = self.context.bot
         return Bot(raw)
 
     def _raise_field_error(self, field: str) -> NoReturn:
-        raise UpdateFieldError(self.update, field)
-
-
-class UpdateFieldError(AttributeError):
-    def __init__(self, update: Update, field: str) -> None:
-        self.update = update
-        self.field = field
-
-    def __str__(self) -> str:
-        return f"No `{self.field}` for `{self.update}`"
+        raise FieldError(self.update, field)
