@@ -7,7 +7,7 @@ class Handler:
     @classmethod
     @abstractmethod
     def build(cls) -> PTBHandler:
-        """Should return PTB-compatible handler."""
+        """Return PTB-compatible handler."""
 
     @classmethod
     def _validate_class_field(cls, field: str) -> None:
@@ -23,7 +23,7 @@ HandlerClass = type[Handler]
 
 
 class HandlerFieldError(AttributeError):
-    def __init__(self, handler: HandlerClass, field: str):
+    def __init__(self, handler: HandlerClass, field: str) -> None:
         self.handler = handler
         self.field = field
 
