@@ -1,5 +1,6 @@
 from .bot import Bot
 from .chat import Chat
+from .query import Query
 from .user import User
 
-__all__ = ["Bot", "Chat", "User"]
+__all__ = ["Bot", "Chat", "User", "Query"]
